@@ -15,12 +15,14 @@ import pytest
 from commoncode.testcase import FileDrivenTesting
 from test_cli import check_data_results
 
+from python_inspector.api import get_index_urls
 from python_inspector.api import resolver_api
 
 test_env = FileDrivenTesting()
 test_env.test_data_dir = os.path.join(os.path.dirname(__file__), "data")
 
 
+@pytest.mark.online
 def test_api_with_specifier():
     expected_file = test_env.get_test_loc("test-api-expected.json", must_exist=False)
     results = resolver_api(
@@ -31,6 +33,7 @@ def test_api_with_specifier():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_specifier_pdt():
     expected_file = test_env.get_test_loc("test-api-pdt-expected.json", must_exist=False)
     results = resolver_api(
@@ -42,6 +45,7 @@ def test_api_with_specifier_pdt():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_requirement_file():
     expected_file = test_env.get_test_loc("test-api-with-requirement-file.json", must_exist=False)
     results = resolver_api(
@@ -52,6 +56,7 @@ def test_api_with_requirement_file():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_prefer_source():
     expected_file = test_env.get_test_loc("test-api-with-prefer-source.json", must_exist=False)
     results = resolver_api(
@@ -63,6 +68,7 @@ def test_api_with_prefer_source():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_recursive_requirement_file():
     requirement_file = test_env.get_test_loc("recursive_requirements/r.txt")
     expected_file = test_env.get_test_loc(
@@ -96,6 +102,7 @@ def test_api_with_wrong_pyver():
         resolver_api(specifiers=["flask==2.1.2"], python_version="3.14", operating_system="linux")
 
 
+@pytest.mark.online
 def test_api_with_python_311():
     expected_file = test_env.get_test_loc("test-api-with-python-311.json", must_exist=False)
     results = resolver_api(
@@ -107,6 +114,7 @@ def test_api_with_python_311():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_lief_python_312():
     expected_file = test_env.get_test_loc("test-api-with-lief-python-312.json", must_exist=False)
     results = resolver_api(
@@ -118,6 +126,7 @@ def test_api_with_lief_python_312():
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
 
 
+@pytest.mark.online
 def test_api_with_partial_setup_py():
     expected_file = test_env.get_test_loc("test-api-with-partial-setup-py.json", must_exist=False)
     results = resolver_api(
@@ -128,3 +137,30 @@ def test_api_with_partial_setup_py():
         analyze_setup_py_insecurely=True,
     )
     check_data_results(results=results.to_dict(generic_paths=True), expected_file=expected_file)
+
+
+def test_get_index_urls():
+    # pass as a tuple
+    index_urls = get_index_urls(
+        index_urls=("https://pypi.org/simple",),
+        extra_data={"extra_index_urls": ["https://pypi.org/simple", "https://example.com/simple"]},
+    )
+
+    expected = ["https://example.com/simple", "https://pypi.org/simple"]
+
+    assert sorted(list(index_urls)) == expected
+
+    # pass as a string
+    index_urls = get_index_urls(
+        index_urls=("https://pypi.org/simple"),
+        extra_data={"extra_index_urls": ["https://pypi.org/simple", "https://example.com/simple"]},
+    )
+
+    assert sorted(list(index_urls)) == expected
+
+    index_urls = get_index_urls(
+        index_urls=("https://pypi.org/simple",),
+        extra_data={"index_url": "https://pypi.org/simple"},
+    )
+
+    assert index_urls == ("https://pypi.org/simple",)
